Backup

Struct Backup 

pub struct Backup<'c, 'p, P: Sqlite3Backup> { /* private fields */ }
RAII wrapper around an online backup handle.

The handle borrows both source and destination connections used to create it, preventing use after either connection is closed.

Implementations

Source

impl<'c, 'p, P: Sqlite3Backup> Backup<'c, 'p, P>

pub fn step(&self, pages: i32) -> Result<()>

Copy up to pages pages.

pub fn remaining(&self) -> i32

Remaining pages in the backup.

pub fn pagecount(&self) -> i32

Total page count in the backup.