Context

Struct Context 

pub struct Context<'p, P: Sqlite3Api> { /* private fields */ }
Context wrapper passed to user-defined functions.

Implementations

Source

impl<'p, P: Sqlite3Api> Context<'p, P>

pub fn result_null(&self)

Set NULL result.

pub fn result_int64(&self, v: i64)

Set integer result.

pub fn result_double(&self, v: f64)

Set floating result.

pub fn result_text(&self, v: &str)

Set text result (provider must copy or retain the bytes as needed).

pub fn result_blob(&self, v: &[u8])

Set blob result (provider must copy or retain the bytes as needed).

pub fn result_error(&self, msg: &str)

Set error result.

pub fn result_value(&self, value: Value)

Set result from an owned Value.