pub struct Error {
pub code: ErrorCode,
pub extended: Option<i32>,
pub message: Option<String>,
}Expand description
Error returned by sqlite-provider operations.
Fields
code: ErrorCodePrimary SQLite-style result code for the failure.
extended: Option<i32>Optional extended SQLite result code when provided by backend.
message: Option<String>Optional human-readable error message from backend or wrapper.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_message(code: ErrorCode, message: impl Into<String>) -> Self
pub fn with_message(code: ErrorCode, message: impl Into<String>) -> Self
Create an error with a primary code and owned message text.
Sourcepub fn from_code(
code: i32,
message: Option<String>,
extended: Option<i32>,
) -> Self
pub fn from_code( code: i32, message: Option<String>, extended: Option<i32>, ) -> Self
Create an error from raw SQLite result code fields.
Create a capability error when a requested optional feature is unavailable.