pub struct Backup<'c, 'p, P: Sqlite3Backup> { /* private fields */ }Expand description
RAII wrapper around an online backup handle.
The handle borrows both source and destination connections used to create it, preventing use after either connection is closed.
Implementations