pub struct Context<'p, P: Sqlite3Api> { /* private fields */ }Expand description
Context wrapper passed to user-defined functions.
Implementations
Sourceimpl<'p, P: Sqlite3Api> Context<'p, P>
impl<'p, P: Sqlite3Api> Context<'p, P>
Sourcepub fn result_null(&self)
pub fn result_null(&self)
Set NULL result.
Sourcepub fn result_int64(&self, v: i64)
pub fn result_int64(&self, v: i64)
Set integer result.
Sourcepub fn result_double(&self, v: f64)
pub fn result_double(&self, v: f64)
Set floating result.
Sourcepub fn result_text(&self, v: &str)
pub fn result_text(&self, v: &str)
Set text result (provider must copy or retain the bytes as needed).
Sourcepub fn result_blob(&self, v: &[u8])
pub fn result_blob(&self, v: &[u8])
Set blob result (provider must copy or retain the bytes as needed).
Sourcepub fn result_error(&self, msg: &str)
pub fn result_error(&self, msg: &str)
Set error result.
Sourcepub fn result_value(&self, value: Value)
pub fn result_value(&self, value: Value)
Set result from an owned Value.